## 0.23.0.20250401 (2025-04-01)

Add `__all__` part 2 (#13719)

---------

Co-authored-by: Avasam <samuel.06@hotmail.com>

## 0.23.0.20241221 (2024-12-21)

Update to mypy 1.14 (#13272)

## 0.23.0.20240724 (2024-07-24)

`setuptools` & `distutils`: `ClassVar` mutables (and tuples) (#12403)

## 0.23.0.20240425 (2024-04-25)

Bump pyright to v1.1.360 (#11810)

## 0.23.0.20240311 (2024-03-11)

Make stubtest pass on libsass/passlib/redis/tree-sitter if you're using Python 3.12 (#11561)

Use PEP 570 syntax in third party stubs (#11554)

## 0.23.0.20240109 (2024-01-09)

Bump libsass to 0.23.* (#11253)

## 0.22.0.20240106 (2024-01-06)

Update typing_extensions imports in third-party stubs (#11245)

## 0.22.0.1 (2023-11-30)

Use `ConvertibleToInt`/`ConvertibleToFloat` in many third-party stubs (#11022)

Note: this may make the latest version of certain stubs packages incompatible with older versions of mypy and pyright.

## 0.22.0.0 (2023-09-01)

Add stubs for libsass (#10638)

